Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type MaterializedPlan ¶
type MaterializedPlan struct {
ConfigRoot string
LeftPath string
RightPath string
LeftLabel string
RightLabel string
}
MaterializedPlan is a diff plan with both sources available as filesystem paths.
type Plan ¶
Plan describes the two materialized inputs and the config root for a diff run.
func ResolvePlan ¶
ResolvePlan maps CLI diff arguments to concrete diff sources.
func (*Plan) Materialize ¶
func (p *Plan) Materialize(ctx context.Context) (*MaterializedPlan, func(), error)
Materialize returns filesystem paths for both sources and one cleanup function.
Click to show internal directories.
Click to hide internal directories.